module.exports = defineTest({
	description: 'tracks reassignments of deoptimized conditional expressions'
});
